@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55800
 #  endif
 #endif
 
@@ -271,6 +271,18 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_84(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KIOCORE_DEPRECATED_VERSION_5_86(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
@@ -338,7 +350,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -348,7 +360,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55800
 #  endif
 #endif
 
@@ -523,6 +535,18 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_84(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KIOCORE_DEPRECATED_VERSION_5_86(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_88(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
