@@ -1,37 +1,29 @@
-/*****************************************************************************
- * Copyright (C) 2006-2010 by Peter Penz <peter.penz@gmx.at>                 *
- * Copyright (C) 2006 by Aaron J. Seigo <aseigo@kde.org>                     *
- * Copyright (C) 2007 by Kevin Ottens <ervin@kde.org>                        *
- * Copyright (C) 2007 by Urs Wolfer <uwolfer @ kde.org>                      *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2010 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2006 Aaron J. Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2007 Urs Wolfer <uwolfer @ kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KURLNAVIGATOR_H
 #define KURLNAVIGATOR_H
 
 #include "kiofilewidgets_export.h"
 
+#include <QByteArray>
 #include <QUrl>
 #include <QWidget>
-#include <QtCore/QByteArray>
+
+#include <memory>
+
+class QMouseEvent;
 
 class KFilePlacesModel;
 class KUrlComboBox;
-class QMouseEvent;
+
+class KUrlNavigatorPrivate;
 
 /**
  * @class KUrlNavigator kurlnavigator.h <KUrlNavigator>
@@ -90,7 +82,7 @@ public:
      * @param parent         Parent widget.
      */
     KUrlNavigator(KFilePlacesModel *placesModel, const QUrl &url, QWidget *parent);
-    virtual ~KUrlNavigator();
+    ~KUrlNavigator() override;
 
     /**
      * @return URL of the location given by the \a historyIndex. If \a historyIndex
@@ -270,8 +262,7 @@ public:
      * If an application supports only some special protocols, they can be set
      * with \a protocols .
      */
-    // KDE5: Think about removing the custom-protocols-property. It had been used
-    // only by one application currently which uses a different approach now.
+    // TODO KF6 rename to setSupportedSchemes to match KDirOperator and KFileWidget
     void setCustomProtocols(const QStringList &protocols);
 
     /**
@@ -290,13 +281,40 @@ public:
      */
     QWidget *dropWidget() const;
 
-#if !defined(KIOFILEWIDGETS_NO_DEPRECATED) && !defined(DOXYGEN_SHOULD_SKIP_THIS)
+    /** 
+     * Sets whether to show hidden folders in the subdirectories popup.
+     * @since 5.87
+     */
+    void setShowHiddenFolders(bool showHiddenFolders);
+
+    /**
+     * Returns whether to show hidden folders in the subdirectories popup.
+     * @since 5.87
+     */
+    bool showHiddenFolders() const;
+
+    /** 
+     * Sets whether to sort hidden folders in the subdirectories popup last.
+     * @since 5.87
+     */
+    void setSortHiddenFoldersLast(bool sortHiddenFoldersLast);
+
+    /**
+     * Returns whether to sort hidden folders in the subdirectories popup last.
+     * @since 5.87
+     */
+    bool sortHiddenFoldersLast() const;
+
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * @return     The current URL of the location.
-     * @deprecated Use KUrlNavigator::locationUrl() instead.
+     * @deprecated Since 4.5, use KUrlNavigator::locationUrl() instead.
      */
-    KIOFILEWIDGETS_DEPRECATED const QUrl &url() const;
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationUrl(int)")
+    const QUrl &url() const;
+#endif
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * @return The portion of the current URL up to the path part given
      * by \a index. Assuming that the current URL is /home/peter/Documents/Music,
@@ -305,33 +323,46 @@ public:
      * - index is 1: /home/peter
      * - index is 2: /home/peter/Documents
      * - index >= 3: /home/peter/Documents/Music
-     * @deprecated It should not be necessary for a client of KUrlNavigator to query this information.
+     * @deprecated Since 4.5. It should not be necessary for a client of KUrlNavigator to query this information.
      */
-    KIOFILEWIDGETS_DEPRECATED QUrl url(int index) const;
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Do not use")
+    QUrl url(int index) const;
+#endif
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * @return URL for the history element with the index \a historyIndex.
      *         The history index 0 represents the most recent URL.
      * @since 4.3
-     * @deprecated Use KUrlNavigator::locationUrl(historyIndex) instead.
+     * @deprecated Since 4.5, use KUrlNavigator::locationUrl(historyIndex) instead.
      */
-    KIOFILEWIDGETS_DEPRECATED QUrl historyUrl(int historyIndex) const;
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationUrl(int)")
+    QUrl historyUrl(int historyIndex) const;
+#endif
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * @return The saved root URL for the current URL (see KUrlNavigator::saveRootUrl()).
-     * @deprecated Use KUrlNavigator::locationState() instead.
+     * @deprecated Since 4.5, use KUrlNavigator::locationState() instead.
      */
-    KIOFILEWIDGETS_DEPRECATED const QUrl &savedRootUrl() const;
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationState(int)")
+    const QUrl &savedRootUrl() const;
+#endif
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * @return The saved contents position of the upper left corner
      *         for the current URL.
-     * @deprecated Use KUrlNavigator::locationState() instead.
+     * @deprecated Since 4.5, use KUrlNavigator::locationState() instead.
      */
-    KIOFILEWIDGETS_DEPRECATED QPoint savedPosition() const;
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::locationState(int)")
+    QPoint savedPosition() const;
+#endif
 
-    /** @deprecated Use setHomeUrl(const QUrl& url) instead. */
-    KIOFILEWIDGETS_DEPRECATED void setHomeUrl(const QString &homeUrl);
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
+    /** @deprecated Since 4.5, use setHomeUrl(const QUrl& url) instead. */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::setHomeUrl(const QUrl&)")
+    void setHomeUrl(const QString &homeUrl);
 #endif
 
 public Q_SLOTS:
@@ -351,29 +382,36 @@ public Q_SLOTS:
      */
     void requestActivation();
 
-#if !defined(DOXYGEN_SHOULD_SKIP_THIS)
+#if !defined(K_DOXYGEN)
     // KDE5: Remove and listen for focus-signal instead
     void setFocus();
 #endif
 
-#if !defined(KIOFILEWIDGETS_NO_DEPRECATED) && !defined(DOXYGEN_SHOULD_SKIP_THIS)
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * Sets the location to \a url.
-     * @deprecated Use KUrlNavigator::setLocationUrl(url).
+     * @deprecated Since 4.5, use KUrlNavigator::setLocationUrl(url).
      */
-    KIOFILEWIDGETS_DEPRECATED void setUrl(const QUrl &url);
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::setLocationUrl(const QUrl&))")
+    void setUrl(const QUrl &url);
+#endif
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * Saves the used root URL of the content for the current history element.
-     * @deprecated Use KUrlNavigator::saveLocationState() instead.
+     * @deprecated Since 4.5, use KUrlNavigator::saveLocationState() instead.
      */
-    KIOFILEWIDGETS_DEPRECATED void saveRootUrl(const QUrl &url);
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::saveLocationState(const QByteArray &)")
+    void saveRootUrl(const QUrl &url);
+#endif
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 5)
     /**
      * Saves the coordinates of the contents for the current history element.
-     * @deprecated Use KUrlNavigator::saveLocationState() instead.
+     * @deprecated Since 4.5, use KUrlNavigator::saveLocationState() instead.
      */
-    KIOFILEWIDGETS_DEPRECATED void savePosition(int x, int y);
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 5, "Use KUrlNavigator::saveLocationState(const QByteArray &)")
+    void savePosition(int x, int y);
 #endif
 
 Q_SIGNALS:
@@ -445,49 +483,41 @@ Q_SIGNALS:
     void urlSelectionRequested(const QUrl &url);
 
 protected:
-#if !defined(DOXYGEN_SHOULD_SKIP_THIS)
+#if !defined(K_DOXYGEN)
     /**
      * If the Escape key is pressed, the navigation bar should switch
      * to the breadcrumb view.
      * @see QWidget::keyPressEvent()
      */
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *event) override;
 
     /**
      * Reimplemented for internal purposes.
      */
-    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    void keyReleaseEvent(QKeyEvent *event) override;
 
     /**
      * Paste the clipboard content as URL, if the middle mouse
      * button has been clicked.
      * @see QWidget::mouseReleaseEvent()
      */
-    void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QMouseEvent *event) override;
 
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    /**
+     * Reimplemented to activate on middle mousse button click
+     */
+    void mousePressEvent(QMouseEvent *event) override;
 
-    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) override;
 
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
+    void wheelEvent(QWheelEvent *event) override;
+
+    bool eventFilter(QObject *watched, QEvent *event) override;
 #endif
 
 private:
-    Q_PRIVATE_SLOT(d, void slotReturnPressed())
-    Q_PRIVATE_SLOT(d, void slotProtocolChanged(const QString &protocol))
-    Q_PRIVATE_SLOT(d, void slotToggleEditableButtonPressed())
-    Q_PRIVATE_SLOT(d, void dropUrls(const QUrl &destination, QDropEvent *))
-    Q_PRIVATE_SLOT(d, void slotNavigatorButtonClicked(const QUrl &url, Qt::MouseButton button))
-    Q_PRIVATE_SLOT(d, void openContextMenu())
-    Q_PRIVATE_SLOT(d, void openPathSelectorMenu())
-    Q_PRIVATE_SLOT(d, void updateButtonVisibility())
-    Q_PRIVATE_SLOT(d, void switchToBreadcrumbMode())
-    Q_PRIVATE_SLOT(d, void slotPathBoxChanged(const QString &text))
-    Q_PRIVATE_SLOT(d, void updateContent())
-
-private:
-    class Private;
-    Private *const d;
+    friend class KUrlNavigatorPrivate;
+    std::unique_ptr<KUrlNavigatorPrivate> const d;
 
     Q_DISABLE_COPY(KUrlNavigator)
 };
